@@ -1,5 +1,3 @@
-#!/usr/bin/env python3
-
 """
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
@@ -16,6 +14,7 @@ import path
 import pytablereader as ptr
 import simplesqlite as sqlite
 import typepy
+from dataproperty import MatrixFormatting
 from loguru import logger
 
 from .__version__ import __version__
@@ -45,6 +44,7 @@ COMMAND_EPILOG = dedent(
 class Default:
     OUTPUT_FILE = "out.sqlite"
     ENCODING = "utf-8"
+    MATRIX_FORMATTING = "header_aligned"
 
 
 def create_database(
@@ -79,7 +79,7 @@ def initialize_logger(name: str, log_level: str) -> None:
     else:
         log_format = "<level>[{level}]</level> {message}"
 
-    logger.add(sys.stdout, colorize=True, format=log_format, level=log_level)
+    logger.add(sys.stderr, colorize=True, format=log_format, level=log_level)
     logger.enable(name)
     ptr.set_logger(True)
     sqlite.set_logger(True)
@@ -111,6 +111,20 @@ def load_convert_config(logger, config_filepath: str, subcommand: str) -> Dict:
     return configs.get(subcommand)
 
 
+def to_matrix_formatting_enum(ctx, param, value) -> MatrixFormatting:
+    import re
+
+    if not value:
+        raise click.BadParameter("empty matrix-formatting")
+
+    nomalized_value = re.sub(r"[\s\-\.]", "_", value).upper()
+
+    try:
+        return MatrixFormatting[nomalized_value]
+    except KeyError as e:
+        raise click.BadParameter(str(e))
+
+
 @click.group(context_settings=CONTEXT_SETTINGS)
 @click.version_option(version=__version__, message="%(prog)s %(version)s")
 @click.option(
@@ -130,7 +144,7 @@ def load_convert_config(logger, config_filepath: str, subcommand: str) -> Dict:
     "--add-primary-key",
     "add_pri_key_name",
     metavar="PRIMARY_KEY_NAME",
-    help="Add 'PRIMARY KEY AUTOINCREMENT' column with the specified name.",
+    help="Add 'PRIMARY KEY AUTOINCREMENT' column to a converted table with the specified name.",
 )
 @click.option(
     "--convert-config",
@@ -169,6 +183,19 @@ def load_convert_config(logger, config_filepath: str, subcommand: str) -> Dict:
         """
     ),
 )
+@click.option(
+    "--matrix-formatting",
+    type=click.Choice(["header_aligned", "trim"], case_sensitive=False),
+    default=Default.MATRIX_FORMATTING,
+    callback=to_matrix_formatting_enum,
+    help=dedent(
+        f"""\
+        header_aligned: fitting table data to header columns.
+        trim: fitting table data to minimum column size.
+        Defaults to {Default.MATRIX_FORMATTING}.
+        """
+    ),
+)
 @click.option("--replace-symbol", "symbol_replace_value", help="Replace symbols in attributes.")
 @click.option("-v", "--verbose", "verbosity_level", count=True)
 @click.option(
@@ -201,6 +228,7 @@ def cmd(
     index_list,
     no_type_inference,
     is_type_hint_header,
+    matrix_formatting: MatrixFormatting,
     symbol_replace_value,
     verbosity_level,
     max_workers,
@@ -214,6 +242,7 @@ def cmd(
     ctx.obj[Context.CONVERT_CONFIG] = convert_config
     ctx.obj[Context.TYPE_INFERENCE] = not no_type_inference
     ctx.obj[Context.TYPE_HINT_HEADER] = is_type_hint_header
+    ctx.obj[Context.MATRIX_FORMATTING] = matrix_formatting
     ctx.obj[Context.VERBOSITY_LEVEL] = verbosity_level
     ctx.obj[Context.MAX_WORKERS] = max_workers
     ctx.obj[Context.LOG_LEVEL] = "INFO" if log_level is None else log_level
@@ -252,7 +281,9 @@ def version(ctx):
     "-f",
     "--format",
     "format_name",
-    type=click.Choice(ptr.TableFileLoader.get_format_names() + IPYNB_FORMAT_NAME_LIST),
+    type=click.Choice(
+        ptr.TableFileLoader.get_format_names() + IPYNB_FORMAT_NAME_LIST, case_sensitive=False
+    ),
     help="Data format to loading (auto-detect from file extensions in default).",
 )
 @click.option(
@@ -291,6 +322,7 @@ def file(ctx, files, recursive, pattern, exclude, follow_symlinks, format_name,
         index_list=ctx.obj.get(Context.INDEX_LIST),
         is_type_inference=ctx.obj[Context.TYPE_INFERENCE],
         is_type_hint_header=ctx.obj[Context.TYPE_HINT_HEADER],
+        matrix_formatting=ctx.obj[Context.MATRIX_FORMATTING],
         verbosity_level=ctx.obj.get(Context.VERBOSITY_LEVEL),
         max_workers=max_workers,
         format_name=format_name,
@@ -322,7 +354,9 @@ def file(ctx, files, recursive, pattern, exclude, follow_symlinks, format_name,
 @cmd.command(epilog=COMMAND_EPILOG)
 @click.argument(
     "format_name",
-    type=click.Choice(ptr.TableTextLoader.get_format_names() + IPYNB_FORMAT_NAME_LIST),
+    type=click.Choice(
+        ptr.TableTextLoader.get_format_names() + IPYNB_FORMAT_NAME_LIST, case_sensitive=False
+    ),
 )
 @click.pass_context
 def stdin(ctx, format_name):
@@ -351,6 +385,7 @@ def stdin(ctx, format_name):
         index_list=ctx.obj.get(Context.INDEX_LIST),
         is_type_inference=ctx.obj[Context.TYPE_INFERENCE],
         is_type_hint_header=ctx.obj[Context.TYPE_HINT_HEADER],
+        matrix_formatting=ctx.obj[Context.MATRIX_FORMATTING],
         verbosity_level=ctx.obj.get(Context.VERBOSITY_LEVEL),
         max_workers=max_workers,
         format_name=format_name,
@@ -367,7 +402,9 @@ def stdin(ctx, format_name):
     "-f",
     "--format",
     "format_name",
-    type=click.Choice(ptr.TableUrlLoader.get_format_names() + IPYNB_FORMAT_NAME_LIST),
+    type=click.Choice(
+        ptr.TableUrlLoader.get_format_names() + IPYNB_FORMAT_NAME_LIST, case_sensitive=False
+    ),
     help="Data format to loading (defaults to html).",
 )
 @click.option(
@@ -423,6 +460,7 @@ def url(ctx, url, format_name, encoding, proxy):
         index_list=ctx.obj.get(Context.INDEX_LIST),
         is_type_inference=ctx.obj[Context.TYPE_INFERENCE],
         is_type_hint_header=ctx.obj[Context.TYPE_HINT_HEADER],
+        matrix_formatting=ctx.obj[Context.MATRIX_FORMATTING],
         verbosity_level=ctx.obj.get(Context.VERBOSITY_LEVEL),
         max_workers=max_workers,
         format_name=format_name,
@@ -466,6 +504,7 @@ def gs(ctx, credentials, title):
         index_list=ctx.obj.get(Context.INDEX_LIST),
         is_type_inference=ctx.obj[Context.TYPE_INFERENCE],
         is_type_hint_header=ctx.obj[Context.TYPE_HINT_HEADER],
+        matrix_formatting=ctx.obj[Context.MATRIX_FORMATTING],
         verbosity_level=ctx.obj.get(Context.VERBOSITY_LEVEL),
         max_workers=max_workers,
     )
@@ -496,7 +535,7 @@ def configure(ctx):
 
 
 @cmd.command(epilog=COMMAND_EPILOG)
-@click.argument("shell", type=click.Choice(["bash", "zsh"]))
+@click.argument("shell", type=click.Choice(["bash", "zsh"], case_sensitive=False))
 @click.pass_context
 def completion(ctx, shell):
     """
@@ -511,6 +550,8 @@ def completion(ctx, shell):
         sqlitebiter completion zsh >> ~/.zshrc
     """
 
+    shell = shell.lower()
+
     if shell == "bash":
         click.echo(
             dedent(
