@@ -6,10 +6,13 @@ import os
 import stat
 from copy import deepcopy
 from errno import EBADF, ENAMETOOLONG, ENOENT, ENOTDIR
+from typing import Optional, Sequence
 
 import msgfy
 import pytablereader as ptr
+from dataproperty import MatrixFormatting
 from path import Path
+from simplesqlite import SimpleSQLite
 
 from .._const import IPYNB_FORMAT_NAME_LIST, TABLE_NOT_FOUND_MSG_FORMAT
 from ._base import SourceInfo, TableConverter
@@ -27,14 +30,15 @@ class FileConverter(TableConverter):
     def __init__(
         self,
         logger,
-        con,
-        symbol_replace_value,
-        add_pri_key_name,
+        con: SimpleSQLite,
+        symbol_replace_value: Optional[str],
+        add_pri_key_name: Optional[str],
         convert_configs,
-        index_list,
-        is_type_inference,
-        is_type_hint_header,
-        verbosity_level,
+        index_list: Sequence[str],
+        is_type_inference: bool,
+        is_type_hint_header: bool,
+        matrix_formatting: MatrixFormatting,
+        verbosity_level: int,
         max_workers: int,
         format_name,
         encoding,
@@ -50,6 +54,7 @@ class FileConverter(TableConverter):
             index_list=index_list,
             is_type_inference=is_type_inference,
             is_type_hint_header=is_type_hint_header,
+            matrix_formatting=matrix_formatting,
             verbosity_level=verbosity_level,
             max_workers=max_workers,
             format_name=format_name,
@@ -93,7 +98,7 @@ class FileConverter(TableConverter):
 
             for table_name in changed_table_name_set:
                 record = deepcopy(source_info_record_base)
-                record.format_name = "ipynb"  # type: ignore
+                record.format_name = "ipynb"
                 record.dst_table = table_name
                 SourceInfo.insert(record)
         else:
@@ -143,7 +148,7 @@ class FileConverter(TableConverter):
                     return
 
                 record = deepcopy(source_info_record_base)
-                record.dst_table = sqlite_tabledata.table_name  # type: ignore
+                record.dst_table = sqlite_tabledata.table_name
                 SourceInfo.insert(record)
         except ptr.OpenError as e:
             logger.error(
@@ -158,7 +163,7 @@ class FileConverter(TableConverter):
                     loader.loader, source_info_record_base
                 ):
                     record = deepcopy(source_info_record_base)
-                    record.dst_table = table_name  # type: ignore
+                    record.dst_table = table_name
                     SourceInfo.insert(record)
             else:
                 logger.error(
