@@ -7,13 +7,15 @@ import os
 import re
 import sys
 from copy import deepcopy
-from typing import Dict, Optional, Pattern, Type
+from typing import Dict, Optional, Pattern, Sequence, Type
 from urllib.parse import urlparse
 
 import msgfy
 import pytablereader as ptr
 import simplesqlite as sqlite
+from dataproperty import MatrixFormatting
 from pytablereader.interface import AbstractTableReader
+from simplesqlite import SimpleSQLite
 from typepy.type import AbstractType
 
 from .._const import IPYNB_FORMAT_NAME_LIST, TABLE_NOT_FOUND_MSG_FORMAT, ExitCode
@@ -53,14 +55,15 @@ class UrlConverter(TableConverter):
     def __init__(
         self,
         logger,
-        con,
-        symbol_replace_value,
-        add_pri_key_name,
+        con: SimpleSQLite,
+        symbol_replace_value: Optional[str],
+        add_pri_key_name: Optional[str],
         convert_configs,
-        index_list,
-        is_type_inference,
-        is_type_hint_header,
-        verbosity_level,
+        index_list: Sequence[str],
+        is_type_inference: bool,
+        is_type_hint_header: bool,
+        matrix_formatting: MatrixFormatting,
+        verbosity_level: int,
         max_workers: int,
         format_name,
         encoding,
@@ -75,6 +78,7 @@ class UrlConverter(TableConverter):
             index_list=index_list,
             is_type_inference=is_type_inference,
             is_type_hint_header=is_type_hint_header,
+            matrix_formatting=matrix_formatting,
             verbosity_level=verbosity_level,
             max_workers=max_workers,
             format_name=format_name,
@@ -100,7 +104,7 @@ class UrlConverter(TableConverter):
 
             for table_name in changed_table_name_set:
                 record = deepcopy(source_info_record_base)
-                record.format_name = "ipynb"  # type: ignore
+                record.format_name = "ipynb"
                 record.dst_table = table_name
                 record.size = nb_size
                 SourceInfo.insert(record)
@@ -135,7 +139,7 @@ class UrlConverter(TableConverter):
                     continue
 
                 record = deepcopy(source_info_record_base)
-                record.dst_table = sqlite_tabledata.table_name  # type: ignore
+                record.dst_table = sqlite_tabledata.table_name
                 SourceInfo.insert(record)
         except ptr.ValidationError as e:
             if loader.format_name == "json":
